# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notebook/v1/notebook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/notebook/v1/notebook.proto',
  package='github.com.metaprov.modelaapi.services.notebook.v1',
  syntax='proto3',
  serialized_options=b'Z2github.com/metaprov/modelaapi/services/notebook/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAgithub.com/metaprov/modelaapi/services/notebook/v1/notebook.proto\x12\x32github.com.metaprov.modelaapi.services.notebook.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbe\x01\n\x14ListNotebooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x03 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x15ListNotebooksResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookList\"\x12\n\x10NotebookResponse\"i\n\x15\x43reateNotebookRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x18\n\x16\x43reateNotebookResponse\"i\n\x15UpdateNotebookRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x18\n\x16UpdateNotebookResponse\"5\n\x12GetNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x13GetNotebookResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteNotebookResponse2\xb5\x08\n\x0fNotebookService\x12\xc5\x01\n\rListNotebooks\x12H.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest\x1aI.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1alpha1/notebooks\x12\xcb\x01\n\x0e\x43reateNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1alpha1/notebooks:\x01*\x12\xc6\x01\n\x0bGetNotebook\x12\x46.github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest\x1aG.github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1alpha1/notebooks/{name}\x12\xe4\x01\n\x0eUpdateNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse\";\x82\xd3\xe4\x93\x02\x35\x1a\x30/api/v1alpha1/notebooks/{notebook.metadata.name}:\x01*\x12\xdb\x01\n\x0e\x44\x65leteNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse\"2\x82\xd3\xe4\x93\x02,**/api/v1/notebooks/{notebook.metadata.name}B4Z2github.com/metaprov/modelaapi/services/notebook/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTNOTEBOOKSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=479,
)

_LISTNOTEBOOKSREQUEST = _descriptor.Descriptor(
  name='ListNotebooksRequest',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTNOTEBOOKSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=479,
)


_LISTNOTEBOOKSRESPONSE = _descriptor.Descriptor(
  name='ListNotebooksResponse',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=591,
)


_NOTEBOOKRESPONSE = _descriptor.Descriptor(
  name='NotebookResponse',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=611,
)


_CREATENOTEBOOKREQUEST = _descriptor.Descriptor(
  name='CreateNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=718,
)


_CREATENOTEBOOKRESPONSE = _descriptor.Descriptor(
  name='CreateNotebookResponse',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=744,
)


_UPDATENOTEBOOKREQUEST = _descriptor.Descriptor(
  name='UpdateNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=851,
)


_UPDATENOTEBOOKRESPONSE = _descriptor.Descriptor(
  name='UpdateNotebookResponse',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=877,
)


_GETNOTEBOOKREQUEST = _descriptor.Descriptor(
  name='GetNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=932,
)


_GETNOTEBOOKRESPONSE = _descriptor.Descriptor(
  name='GetNotebookResponse',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1051,
)


_DELETENOTEBOOKREQUEST = _descriptor.Descriptor(
  name='DeleteNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1109,
)


_DELETENOTEBOOKRESPONSE = _descriptor.Descriptor(
  name='DeleteNotebookResponse',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1135,
)

_LISTNOTEBOOKSREQUEST_LABELSENTRY.containing_type = _LISTNOTEBOOKSREQUEST
_LISTNOTEBOOKSREQUEST.fields_by_name['labels'].message_type = _LISTNOTEBOOKSREQUEST_LABELSENTRY
_LISTNOTEBOOKSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKLIST
_CREATENOTEBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK
_UPDATENOTEBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK
_GETNOTEBOOKRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK
DESCRIPTOR.message_types_by_name['ListNotebooksRequest'] = _LISTNOTEBOOKSREQUEST
DESCRIPTOR.message_types_by_name['ListNotebooksResponse'] = _LISTNOTEBOOKSRESPONSE
DESCRIPTOR.message_types_by_name['NotebookResponse'] = _NOTEBOOKRESPONSE
DESCRIPTOR.message_types_by_name['CreateNotebookRequest'] = _CREATENOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['CreateNotebookResponse'] = _CREATENOTEBOOKRESPONSE
DESCRIPTOR.message_types_by_name['UpdateNotebookRequest'] = _UPDATENOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['UpdateNotebookResponse'] = _UPDATENOTEBOOKRESPONSE
DESCRIPTOR.message_types_by_name['GetNotebookRequest'] = _GETNOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['GetNotebookResponse'] = _GETNOTEBOOKRESPONSE
DESCRIPTOR.message_types_by_name['DeleteNotebookRequest'] = _DELETENOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['DeleteNotebookResponse'] = _DELETENOTEBOOKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListNotebooksRequest = _reflection.GeneratedProtocolMessageType('ListNotebooksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest)
  })
_sym_db.RegisterMessage(ListNotebooksRequest)
_sym_db.RegisterMessage(ListNotebooksRequest.LabelsEntry)

ListNotebooksResponse = _reflection.GeneratedProtocolMessageType('ListNotebooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse)
  })
_sym_db.RegisterMessage(ListNotebooksResponse)

NotebookResponse = _reflection.GeneratedProtocolMessageType('NotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.NotebookResponse)
  })
_sym_db.RegisterMessage(NotebookResponse)

CreateNotebookRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRequest)

CreateNotebookResponse = _reflection.GeneratedProtocolMessageType('CreateNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse)
  })
_sym_db.RegisterMessage(CreateNotebookResponse)

UpdateNotebookRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRequest)

UpdateNotebookResponse = _reflection.GeneratedProtocolMessageType('UpdateNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse)
  })
_sym_db.RegisterMessage(UpdateNotebookResponse)

GetNotebookRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest)
  })
_sym_db.RegisterMessage(GetNotebookRequest)

GetNotebookResponse = _reflection.GeneratedProtocolMessageType('GetNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse)
  })
_sym_db.RegisterMessage(GetNotebookResponse)

DeleteNotebookRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRequest)

DeleteNotebookResponse = _reflection.GeneratedProtocolMessageType('DeleteNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse)
  })
_sym_db.RegisterMessage(DeleteNotebookResponse)


DESCRIPTOR._options = None
_LISTNOTEBOOKSREQUEST_LABELSENTRY._options = None

_NOTEBOOKSERVICE = _descriptor.ServiceDescriptor(
  name='NotebookService',
  full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1138,
  serialized_end=2215,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListNotebooks',
    full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookService.ListNotebooks',
    index=0,
    containing_service=None,
    input_type=_LISTNOTEBOOKSREQUEST,
    output_type=_LISTNOTEBOOKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1alpha1/notebooks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNotebook',
    full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookService.CreateNotebook',
    index=1,
    containing_service=None,
    input_type=_CREATENOTEBOOKREQUEST,
    output_type=_CREATENOTEBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/api/v1alpha1/notebooks:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotebook',
    full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookService.GetNotebook',
    index=2,
    containing_service=None,
    input_type=_GETNOTEBOOKREQUEST,
    output_type=_GETNOTEBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/api/v1alpha1/notebooks/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotebook',
    full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookService.UpdateNotebook',
    index=3,
    containing_service=None,
    input_type=_UPDATENOTEBOOKREQUEST,
    output_type=_UPDATENOTEBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0320/api/v1alpha1/notebooks/{notebook.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNotebook',
    full_name='github.com.metaprov.modelaapi.services.notebook.v1.NotebookService.DeleteNotebook',
    index=4,
    containing_service=None,
    input_type=_DELETENOTEBOOKREQUEST,
    output_type=_DELETENOTEBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002,**/api/v1/notebooks/{notebook.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOTEBOOKSERVICE)

DESCRIPTOR.services_by_name['NotebookService'] = _NOTEBOOKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/attachment/v1/attachment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/attachment/v1/attachment.proto',
  package='github.com.metaprov.modelaapi.services.attachment.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/attachment/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/attachment/v1/attachment.proto\x12\x34github.com.metaprov.modelaapi.services.attachment.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xc4\x01\n\x16ListAttachmentsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x17ListAttachmentsResponse\x12T\n\x05items\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AttachmentList\"\x14\n\x12\x41ttachmentResponse\"|\n\x17\x43reateAttachmentRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\x12\x10\n\x08password\x18\x02 \x01(\t\"\x1a\n\x18\x43reateAttachmentResponse\"j\n\x17UpdateAttachmentRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x1a\n\x18UpdateAttachmentResponse\"7\n\x14GetAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x15GetAttachmentResponse\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"A\n\x1eGetAttachmentNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x1fGetAttachmentNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\":\n\x17\x44\x65leteAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteAttachmentResponse\"\x1a\n\x18\x41ttachmentCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"K\n\x16\x41ttachmentLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"(\n\x17\x41ttachmentLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t\"=\n\x1a\x41ttachmentGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"(\n\x17\x41ttachmentLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"h\n\x15\x43hangePasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03old\x18\x03 \x01(\t\x12\x0b\n\x03new\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x05 \x01(\t\"\x18\n\x16\x43hangePasswordResponse\"Z\n\x14ResetPasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03new\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x04 \x01(\t\"\x16\n\x14ResetPasswordReponse2\x86\t\n\x11\x41ttachmentService\x12\xc7\x01\n\x0fListAttachments\x12L.github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest\x1aM.github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/attachments\x12\xd6\x01\n\x10\x43reateAttachment\x12M.github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest\x1aN.github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x0f/v1/attachments:\nattachment\x12\xd4\x01\n\rGetAttachment\x12J.github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest\x1aK.github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/{namespace}/attachments/{name}\x12\x92\x02\n\x10UpdateAttachment\x12M.github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentRequest\x1aN.github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentResponse\"_\x82\xd3\xe4\x93\x02Y\x1aK/v1/{attachment.metadata.namespace}/attachments//{attachment.metadata.name}:\nattachment\x12\xe1\x01\n\x10\x44\x65leteAttachment\x12M.github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest\x1aN.github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentResponse\".\x82\xd3\xe4\x93\x02(*&/api/{namespace}/v1/attachments/{name}B6Z4github.com/metaprov/modelaapi/services/attachment/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTATTACHMENTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=488,
)

_LISTATTACHMENTSREQUEST = _descriptor.Descriptor(
  name='ListAttachmentsRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTATTACHMENTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=488,
)


_LISTATTACHMENTSRESPONSE = _descriptor.Descriptor(
  name='ListAttachmentsResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=601,
)


_ATTACHMENTRESPONSE = _descriptor.Descriptor(
  name='AttachmentResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=623,
)


_CREATEATTACHMENTREQUEST = _descriptor.Descriptor(
  name='CreateAttachmentRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=749,
)


_CREATEATTACHMENTRESPONSE = _descriptor.Descriptor(
  name='CreateAttachmentResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=777,
)


_UPDATEATTACHMENTREQUEST = _descriptor.Descriptor(
  name='UpdateAttachmentRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=885,
)


_UPDATEATTACHMENTRESPONSE = _descriptor.Descriptor(
  name='UpdateAttachmentResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=913,
)


_GETATTACHMENTREQUEST = _descriptor.Descriptor(
  name='GetAttachmentRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=915,
  serialized_end=970,
)


_GETATTACHMENTRESPONSE = _descriptor.Descriptor(
  name='GetAttachmentResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1090,
)


_GETATTACHMENTNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetAttachmentNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1157,
)


_GETATTACHMENTNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetAttachmentNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1159,
  serialized_end=1277,
)


_DELETEATTACHMENTREQUEST = _descriptor.Descriptor(
  name='DeleteAttachmentRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1337,
)


_DELETEATTACHMENTRESPONSE = _descriptor.Descriptor(
  name='DeleteAttachmentResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1339,
  serialized_end=1365,
)


_ATTACHMENTCREATERESPONSE = _descriptor.Descriptor(
  name='AttachmentCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1393,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1411,
)


_RESETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ResetPasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1413,
  serialized_end=1436,
)


_ATTACHMENTLOGINREQUEST = _descriptor.Descriptor(
  name='AttachmentLoginRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1513,
)


_ATTACHMENTLOGINRESPONSE = _descriptor.Descriptor(
  name='AttachmentLoginResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1555,
)


_ATTACHMENTGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='AttachmentGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1618,
)


_ATTACHMENTLOGOUTREQUEST = _descriptor.Descriptor(
  name='AttachmentLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1620,
  serialized_end=1660,
)


_CHANGEPASSWORDREQUEST = _descriptor.Descriptor(
  name='ChangePasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest.old', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest.new', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest.confirmedNew', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1766,
)


_CHANGEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ChangePasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1792,
)


_RESETPASSWORDREQUEST = _descriptor.Descriptor(
  name='ResetPasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordRequest.new', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordRequest.confirmedNew', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1884,
)


_RESETPASSWORDREPONSE = _descriptor.Descriptor(
  name='ResetPasswordReponse',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1886,
  serialized_end=1908,
)

_LISTATTACHMENTSREQUEST_LABELSENTRY.containing_type = _LISTATTACHMENTSREQUEST
_LISTATTACHMENTSREQUEST.fields_by_name['labels'].message_type = _LISTATTACHMENTSREQUEST_LABELSENTRY
_LISTATTACHMENTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ATTACHMENTLIST
_CREATEATTACHMENTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ATTACHMENT
_UPDATEATTACHMENTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ATTACHMENT
_GETATTACHMENTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ATTACHMENT
_GETATTACHMENTNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListAttachmentsRequest'] = _LISTATTACHMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListAttachmentsResponse'] = _LISTATTACHMENTSRESPONSE
DESCRIPTOR.message_types_by_name['AttachmentResponse'] = _ATTACHMENTRESPONSE
DESCRIPTOR.message_types_by_name['CreateAttachmentRequest'] = _CREATEATTACHMENTREQUEST
DESCRIPTOR.message_types_by_name['CreateAttachmentResponse'] = _CREATEATTACHMENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAttachmentRequest'] = _UPDATEATTACHMENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateAttachmentResponse'] = _UPDATEATTACHMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetAttachmentRequest'] = _GETATTACHMENTREQUEST
DESCRIPTOR.message_types_by_name['GetAttachmentResponse'] = _GETATTACHMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetAttachmentNamespacesRequest'] = _GETATTACHMENTNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetAttachmentNamespacesResponse'] = _GETATTACHMENTNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAttachmentRequest'] = _DELETEATTACHMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAttachmentResponse'] = _DELETEATTACHMENTRESPONSE
DESCRIPTOR.message_types_by_name['AttachmentCreateResponse'] = _ATTACHMENTCREATERESPONSE
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordResponse'] = _RESETPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['AttachmentLoginRequest'] = _ATTACHMENTLOGINREQUEST
DESCRIPTOR.message_types_by_name['AttachmentLoginResponse'] = _ATTACHMENTLOGINRESPONSE
DESCRIPTOR.message_types_by_name['AttachmentGetByNameRequest'] = _ATTACHMENTGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['AttachmentLogoutRequest'] = _ATTACHMENTLOGOUTREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordRequest'] = _CHANGEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordResponse'] = _CHANGEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordRequest'] = _RESETPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ResetPasswordReponse'] = _RESETPASSWORDREPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAttachmentsRequest = _reflection.GeneratedProtocolMessageType('ListAttachmentsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTATTACHMENTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTATTACHMENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest)
  })
_sym_db.RegisterMessage(ListAttachmentsRequest)
_sym_db.RegisterMessage(ListAttachmentsRequest.LabelsEntry)

ListAttachmentsResponse = _reflection.GeneratedProtocolMessageType('ListAttachmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTACHMENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsResponse)
  })
_sym_db.RegisterMessage(ListAttachmentsResponse)

AttachmentResponse = _reflection.GeneratedProtocolMessageType('AttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentResponse)
  })
_sym_db.RegisterMessage(AttachmentResponse)

CreateAttachmentRequest = _reflection.GeneratedProtocolMessageType('CreateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest)
  })
_sym_db.RegisterMessage(CreateAttachmentRequest)

CreateAttachmentResponse = _reflection.GeneratedProtocolMessageType('CreateAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentResponse)
  })
_sym_db.RegisterMessage(CreateAttachmentResponse)

UpdateAttachmentRequest = _reflection.GeneratedProtocolMessageType('UpdateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentRequest)
  })
_sym_db.RegisterMessage(UpdateAttachmentRequest)

UpdateAttachmentResponse = _reflection.GeneratedProtocolMessageType('UpdateAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentResponse)
  })
_sym_db.RegisterMessage(UpdateAttachmentResponse)

GetAttachmentRequest = _reflection.GeneratedProtocolMessageType('GetAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest)
  })
_sym_db.RegisterMessage(GetAttachmentRequest)

GetAttachmentResponse = _reflection.GeneratedProtocolMessageType('GetAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse)
  })
_sym_db.RegisterMessage(GetAttachmentResponse)

GetAttachmentNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetAttachmentNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesRequest)
  })
_sym_db.RegisterMessage(GetAttachmentNamespacesRequest)

GetAttachmentNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetAttachmentNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesResponse)
  })
_sym_db.RegisterMessage(GetAttachmentNamespacesResponse)

DeleteAttachmentRequest = _reflection.GeneratedProtocolMessageType('DeleteAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest)
  })
_sym_db.RegisterMessage(DeleteAttachmentRequest)

DeleteAttachmentResponse = _reflection.GeneratedProtocolMessageType('DeleteAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentResponse)
  })
_sym_db.RegisterMessage(DeleteAttachmentResponse)

AttachmentCreateResponse = _reflection.GeneratedProtocolMessageType('AttachmentCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentCreateResponse)
  })
_sym_db.RegisterMessage(AttachmentCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

AttachmentLoginRequest = _reflection.GeneratedProtocolMessageType('AttachmentLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginRequest)
  })
_sym_db.RegisterMessage(AttachmentLoginRequest)

AttachmentLoginResponse = _reflection.GeneratedProtocolMessageType('AttachmentLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLoginResponse)
  })
_sym_db.RegisterMessage(AttachmentLoginResponse)

AttachmentGetByNameRequest = _reflection.GeneratedProtocolMessageType('AttachmentGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentGetByNameRequest)
  })
_sym_db.RegisterMessage(AttachmentGetByNameRequest)

AttachmentLogoutRequest = _reflection.GeneratedProtocolMessageType('AttachmentLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentLogoutRequest)
  })
_sym_db.RegisterMessage(AttachmentLogoutRequest)

ChangePasswordRequest = _reflection.GeneratedProtocolMessageType('ChangePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordRequest)
  })
_sym_db.RegisterMessage(ChangePasswordRequest)

ChangePasswordResponse = _reflection.GeneratedProtocolMessageType('ChangePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ChangePasswordResponse)
  })
_sym_db.RegisterMessage(ChangePasswordResponse)

ResetPasswordRequest = _reflection.GeneratedProtocolMessageType('ResetPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordRequest)
  })
_sym_db.RegisterMessage(ResetPasswordRequest)

ResetPasswordReponse = _reflection.GeneratedProtocolMessageType('ResetPasswordReponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ResetPasswordReponse)
  })
_sym_db.RegisterMessage(ResetPasswordReponse)


DESCRIPTOR._options = None
_LISTATTACHMENTSREQUEST_LABELSENTRY._options = None

_ATTACHMENTSERVICE = _descriptor.ServiceDescriptor(
  name='AttachmentService',
  full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1911,
  serialized_end=3069,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAttachments',
    full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService.ListAttachments',
    index=0,
    containing_service=None,
    input_type=_LISTATTACHMENTSREQUEST,
    output_type=_LISTATTACHMENTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/attachments',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAttachment',
    full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService.CreateAttachment',
    index=1,
    containing_service=None,
    input_type=_CREATEATTACHMENTREQUEST,
    output_type=_CREATEATTACHMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\017/v1/attachments:\nattachment',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAttachment',
    full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService.GetAttachment',
    index=2,
    containing_service=None,
    input_type=_GETATTACHMENTREQUEST,
    output_type=_GETATTACHMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002$\022\"/v1/{namespace}/attachments/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAttachment',
    full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService.UpdateAttachment',
    index=3,
    containing_service=None,
    input_type=_UPDATEATTACHMENTREQUEST,
    output_type=_UPDATEATTACHMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002Y\032K/v1/{attachment.metadata.namespace}/attachments//{attachment.metadata.name}:\nattachment',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAttachment',
    full_name='github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService.DeleteAttachment',
    index=4,
    containing_service=None,
    input_type=_DELETEATTACHMENTREQUEST,
    output_type=_DELETEATTACHMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002(*&/api/{namespace}/v1/attachments/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ATTACHMENTSERVICE)

DESCRIPTOR.services_by_name['AttachmentService'] = _ATTACHMENTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictor/v1/predictor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/predictor/v1/predictor.proto',
  package='github.com.metaprov.modelaapi.services.predictor.v1',
  syntax='proto3',
  serialized_options=b'Z3github.com/metaprov/modelaapi/services/predictor/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCgithub.com/metaprov/modelaapi/services/predictor/v1/predictor.proto\x12\x33github.com.metaprov.modelaapi.services.predictor.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xc1\x01\n\x15ListPredictorsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x16ListPredictorsResponse\x12W\n\x05items\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictorList\"\x19\n\x17\x43reatePredictorResponse\"l\n\x16\x43reatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"l\n\x16UpdatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x19\n\x17UpdatePredictorResponse\"6\n\x13GetPredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n\x14GetPredictorResponse\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16\x44\x65letePredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x44\x65letePredictorResponse\"E\n\x0fRollbackRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmodelName\x18\x03 \x01(\t\"\x12\n\x10RollbackResponse\"T\n\x11PredictOneRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ields\x18\x03 \x01(\t\x12\x0e\n\x06values\x18\x04 \x01(\t\"\xe4\x01\n\x12PredictOneResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12\x61\n\x05proba\x18\x05 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry\x1a,\n\nProbaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x32\xb9\x0b\n\x10PredictorService\x12\xc1\x01\n\x0eListPredictors\x12J.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest\x1aK.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/predictors\x12\xc7\x01\n\x0f\x43reatePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/predictors:\x01*\x12\xc2\x01\n\x0cGetPredictor\x12H.github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest\x1aI.github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/predictors/{name}\x12\xe1\x01\n\x0fUpdatePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse\"3\x82\xd3\xe4\x93\x02-\x1a(/v1/predictors/{predictor.metadata.name}:\x01*\x12\xd5\x01\n\x08RollBack\x12\x44.github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest\x1a\x45.github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/v1/predictors/{predictor.metadata.name}:rollback:\x01*\x12\xcb\x01\n\x0f\x44\x65letePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse\"\x1d\x82\xd3\xe4\x93\x02\x17*\x15/v1/predictors/{name}\x12\xc7\x01\n\nPredictOne\x12\x46.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest\x1aG.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse\"(\x82\xd3\xe4\x93\x02\"\" /v1/predictors/{name}:predictoneB5Z3github.com/metaprov/modelaapi/services/predictor/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTPREDICTORSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=423,
)

_LISTPREDICTORSREQUEST = _descriptor.Descriptor(
  name='ListPredictorsRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPREDICTORSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=423,
)


_LISTPREDICTORSRESPONSE = _descriptor.Descriptor(
  name='ListPredictorsResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=538,
)


_CREATEPREDICTORRESPONSE = _descriptor.Descriptor(
  name='CreatePredictorResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=565,
)


_CREATEPREDICTORREQUEST = _descriptor.Descriptor(
  name='CreatePredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=675,
)


_UPDATEPREDICTORREQUEST = _descriptor.Descriptor(
  name='UpdatePredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=785,
)


_UPDATEPREDICTORRESPONSE = _descriptor.Descriptor(
  name='UpdatePredictorResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=812,
)


_GETPREDICTORREQUEST = _descriptor.Descriptor(
  name='GetPredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=868,
)


_GETPREDICTORRESPONSE = _descriptor.Descriptor(
  name='GetPredictorResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=990,
)


_DELETEPREDICTORREQUEST = _descriptor.Descriptor(
  name='DeletePredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1049,
)


_DELETEPREDICTORRESPONSE = _descriptor.Descriptor(
  name='DeletePredictorResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1076,
)


_ROLLBACKREQUEST = _descriptor.Descriptor(
  name='RollbackRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest.modelName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1147,
)


_ROLLBACKRESPONSE = _descriptor.Descriptor(
  name='RollbackResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=1167,
)


_PREDICTONEREQUEST = _descriptor.Descriptor(
  name='PredictOneRequest',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest.fields', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest.values', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1253,
)


_PREDICTONERESPONSE_PROBAENTRY = _descriptor.Descriptor(
  name='ProbaEntry',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1484,
)

_PREDICTONERESPONSE = _descriptor.Descriptor(
  name='PredictOneResponse',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.score', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proba', full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.proba', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PREDICTONERESPONSE_PROBAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1484,
)

_LISTPREDICTORSREQUEST_LABELSENTRY.containing_type = _LISTPREDICTORSREQUEST
_LISTPREDICTORSREQUEST.fields_by_name['labels'].message_type = _LISTPREDICTORSREQUEST_LABELSENTRY
_LISTPREDICTORSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTORLIST
_CREATEPREDICTORREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_UPDATEPREDICTORREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_GETPREDICTORRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_PREDICTONERESPONSE_PROBAENTRY.containing_type = _PREDICTONERESPONSE
_PREDICTONERESPONSE.fields_by_name['proba'].message_type = _PREDICTONERESPONSE_PROBAENTRY
DESCRIPTOR.message_types_by_name['ListPredictorsRequest'] = _LISTPREDICTORSREQUEST
DESCRIPTOR.message_types_by_name['ListPredictorsResponse'] = _LISTPREDICTORSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictorResponse'] = _CREATEPREDICTORRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictorRequest'] = _CREATEPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictorRequest'] = _UPDATEPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictorResponse'] = _UPDATEPREDICTORRESPONSE
DESCRIPTOR.message_types_by_name['GetPredictorRequest'] = _GETPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['GetPredictorResponse'] = _GETPREDICTORRESPONSE
DESCRIPTOR.message_types_by_name['DeletePredictorRequest'] = _DELETEPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['DeletePredictorResponse'] = _DELETEPREDICTORRESPONSE
DESCRIPTOR.message_types_by_name['RollbackRequest'] = _ROLLBACKREQUEST
DESCRIPTOR.message_types_by_name['RollbackResponse'] = _ROLLBACKRESPONSE
DESCRIPTOR.message_types_by_name['PredictOneRequest'] = _PREDICTONEREQUEST
DESCRIPTOR.message_types_by_name['PredictOneResponse'] = _PREDICTONERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPredictorsRequest = _reflection.GeneratedProtocolMessageType('ListPredictorsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTORSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTORSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest)
  })
_sym_db.RegisterMessage(ListPredictorsRequest)
_sym_db.RegisterMessage(ListPredictorsRequest.LabelsEntry)

ListPredictorsResponse = _reflection.GeneratedProtocolMessageType('ListPredictorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse)
  })
_sym_db.RegisterMessage(ListPredictorsResponse)

CreatePredictorResponse = _reflection.GeneratedProtocolMessageType('CreatePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse)
  })
_sym_db.RegisterMessage(CreatePredictorResponse)

CreatePredictorRequest = _reflection.GeneratedProtocolMessageType('CreatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest)
  })
_sym_db.RegisterMessage(CreatePredictorRequest)

UpdatePredictorRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest)
  })
_sym_db.RegisterMessage(UpdatePredictorRequest)

UpdatePredictorResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse)
  })
_sym_db.RegisterMessage(UpdatePredictorResponse)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

GetPredictorResponse = _reflection.GeneratedProtocolMessageType('GetPredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse)
  })
_sym_db.RegisterMessage(GetPredictorResponse)

DeletePredictorRequest = _reflection.GeneratedProtocolMessageType('DeletePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest)
  })
_sym_db.RegisterMessage(DeletePredictorRequest)

DeletePredictorResponse = _reflection.GeneratedProtocolMessageType('DeletePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse)
  })
_sym_db.RegisterMessage(DeletePredictorResponse)

RollbackRequest = _reflection.GeneratedProtocolMessageType('RollbackRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest)
  })
_sym_db.RegisterMessage(RollbackRequest)

RollbackResponse = _reflection.GeneratedProtocolMessageType('RollbackResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse)
  })
_sym_db.RegisterMessage(RollbackResponse)

PredictOneRequest = _reflection.GeneratedProtocolMessageType('PredictOneRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTONEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest)
  })
_sym_db.RegisterMessage(PredictOneRequest)

PredictOneResponse = _reflection.GeneratedProtocolMessageType('PredictOneResponse', (_message.Message,), {

  'ProbaEntry' : _reflection.GeneratedProtocolMessageType('ProbaEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREDICTONERESPONSE_PROBAENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry)
    })
  ,
  'DESCRIPTOR' : _PREDICTONERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse)
  })
_sym_db.RegisterMessage(PredictOneResponse)
_sym_db.RegisterMessage(PredictOneResponse.ProbaEntry)


DESCRIPTOR._options = None
_LISTPREDICTORSREQUEST_LABELSENTRY._options = None
_PREDICTONERESPONSE_PROBAENTRY._options = None

_PREDICTORSERVICE = _descriptor.ServiceDescriptor(
  name='PredictorService',
  full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1487,
  serialized_end=2952,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPredictors',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.ListPredictors',
    index=0,
    containing_service=None,
    input_type=_LISTPREDICTORSREQUEST,
    output_type=_LISTPREDICTORSRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1/predictors',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePredictor',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.CreatePredictor',
    index=1,
    containing_service=None,
    input_type=_CREATEPREDICTORREQUEST,
    output_type=_CREATEPREDICTORRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/predictors:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPredictor',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.GetPredictor',
    index=2,
    containing_service=None,
    input_type=_GETPREDICTORREQUEST,
    output_type=_GETPREDICTORRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/predictors/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePredictor',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.UpdatePredictor',
    index=3,
    containing_service=None,
    input_type=_UPDATEPREDICTORREQUEST,
    output_type=_UPDATEPREDICTORRESPONSE,
    serialized_options=b'\202\323\344\223\002-\032(/v1/predictors/{predictor.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RollBack',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.RollBack',
    index=4,
    containing_service=None,
    input_type=_ROLLBACKREQUEST,
    output_type=_ROLLBACKRESPONSE,
    serialized_options=b'\202\323\344\223\0026\"1/v1/predictors/{predictor.metadata.name}:rollback:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePredictor',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.DeletePredictor',
    index=5,
    containing_service=None,
    input_type=_DELETEPREDICTORREQUEST,
    output_type=_DELETEPREDICTORRESPONSE,
    serialized_options=b'\202\323\344\223\002\027*\025/v1/predictors/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PredictOne',
    full_name='github.com.metaprov.modelaapi.services.predictor.v1.PredictorService.PredictOne',
    index=6,
    containing_service=None,
    input_type=_PREDICTONEREQUEST,
    output_type=_PREDICTONERESPONSE,
    serialized_options=b'\202\323\344\223\002\"\" /v1/predictors/{name}:predictone',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTORSERVICE)

DESCRIPTOR.services_by_name['PredictorService'] = _PREDICTORSERVICE

# @@protoc_insertion_point(module_scope)
